#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-10-06
# File  : metrics/check_ntp.py
#
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info
)

metric_info['ntp_offset'] = {
    'title': _('Offset'),
    'unit': 's',
    'color': '#9a52bf',
}


metric_info['ntp_delay'] = {
    'title': _('Delay'),
    'help': _(''),
    'unit': 's',
    'color': '26/a',
}

metric_info['ntp_root_dispersion'] = {
    'title': _('Root dispersion'),
    'help': _(''),
    'unit': 's',
    'color': '32/a',
}


graph_info['check_ntp_offset'] = {
    'title': _('Time offset'),
    'metrics': [
        ('ntp_offset', 'area'),
    ],
    'scalars': [
        ('ntp_offset:crit', _('Upper critical level')),
        ('ntp_offset:warn', _('Upper warning level')),
        ('0,ntp_offset:warn,-', _('Lower warning level')),
        ('0,ntp_offset:crit,-', _('Lower critical level')),
    ],
    'range': ('0,ntp_offset:crit,-', 'ntp_offset:crit'),
}

graph_info['check_ntp_delay'] = {
    'title': _('Delay'),
    'metrics': [
        ('ntp_delay', 'area'),
    ],
    'scalars': [
        ('ntp_delay:crit', _('Critical')),
        ('ntp_delay:warn', _('Warning')),
    ],
    'range': (0, 'ntp_delay:max'),
}


graph_info['check_ntp_dispersion'] = {
    'title': _('Root dispersion'),
    'metrics': [
        ('ntp_root_dispersion', 'area'),
    ],
    'scalars': [
        ('ntp_root_dispersion:crit', _('Critical')),
        ('ntp_root_dispersion:warn', _('Warning')),
    ],
    'range': (0, 'ntp_root_dispersion:max'),
}


perfometer_info.append({
    'type': 'logarithmic',
    'metric': 'ntp_offset',
    'half_value': 1.0,
    'exponent': 10.0,
})
